==> grizzly-websockets-2.3.1-sources.jar: org/glassfish/grizzly/websockets/OptimizedBroadcaster.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.grizzly.websockets;

/**
 * The default {@link Broadcaster} optimized to send the same text to a set of
 * clients.
 * NOTE: works with {@link DefaultWebSocket}s and inherited classes.
 * 
 * @author Alexey Stashok
 */
public class OptimizedBroadcaster implements Broadcaster {

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final String text) {
        
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(text);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException wse) {
                }
            }
        }
    }
    
    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final byte[] binary) {
        
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(binary);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException e) {
                }
            }
        }
    }

    @Override
    public void broadcastFragment(Iterable<? extends WebSocket> recipients,
            String text, boolean last) {
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(text, last);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException wse) {
                }
            }
        }
    }

    @Override
    public void broadcastFragment(Iterable<? extends WebSocket> recipients, byte[] binary, boolean last) {
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (!websocket.isConnected()) {
                continue;
            } else {
                
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(binary, last);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException wse) {
                }
            }
        }
    }
}

==> grizzly-websockets-2.3.22-sources.jar: org/glassfish/grizzly/websockets/OptimizedBroadcaster.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.grizzly.websockets;

/**
 * The default {@link Broadcaster} optimized to send the same text to a set of
 * clients.
 * NOTE: works with {@link DefaultWebSocket}s and inherited classes.
 * 
 * @author Alexey Stashok
 */
public class OptimizedBroadcaster implements Broadcaster {

    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final String text) {
        
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (websocket.isConnected()) {
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(text);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }
    
    /**
     * {@inheritDoc}
     */
    @Override
    public void broadcast(final Iterable<? extends WebSocket> recipients,
            final byte[] binary) {
        
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (websocket.isConnected()) {
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(binary);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }

    @Override
    public void broadcastFragment(Iterable<? extends WebSocket> recipients,
            String text, boolean last) {
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (websocket.isConnected()) {
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(text, last);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }

    @Override
    public void broadcastFragment(Iterable<? extends WebSocket> recipients, byte[] binary, boolean last) {
        byte[] rawDataToSend = null;
        
        for (WebSocket websocket : recipients) {
            final DefaultWebSocket defaultWebSocket = (DefaultWebSocket) websocket;
            
            if (websocket.isConnected()) {
                if (rawDataToSend == null) {
                    rawDataToSend = defaultWebSocket.toRawData(binary, last);
                }
                
                try {
                    defaultWebSocket.sendRaw(rawDataToSend);
                } catch (WebSocketException ignored) {
                }
            }
        }
    }
}
